@@ -1,6 +1,8 @@
 from .handler import generate_alternatives, translate
 from .config import Config
 
+__all__ = ["generate_alternatives", "translate", "Config"]
+
 import pkg_resources as pkg  # part of setuptools
 
 package = "metamorph"
@@ -8,4 +10,6 @@ package = "metamorph"
 try:
     version = pkg.require(package)[0].version
 except pkg.DistributionNotFound:
-    version = "dirty"
\ No newline at end of file
+    version = "dirty"
+
+__version__ = version
\ No newline at end of file
